package com.ruoyi.web.controller.invest;

import java.util.List;
import java.util.stream.Collectors;
import javax.servlet.http.HttpServletResponse;

import com.ruoyi.common.config.RuoYiConfig;
import com.ruoyi.common.enums.FileType;
import com.ruoyi.common.utils.file.FileUploadUtils;
import com.ruoyi.common.utils.file.FileUtils;
import com.ruoyi.common.utils.uuid.IdUtils;
import com.ruoyi.framework.config.ServerConfig;
import com.ruoyi.invest.domain.TProjectCirculation;
import com.ruoyi.invest.service.ITProjectCirculationService;
import com.ruoyi.system.service.ISysDictDataService;
import com.ruoyi.tool.domain.TUnifyFile;
import com.ruoyi.tool.service.ITUnifyFileService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.invest.domain.TProjectContract;
import com.ruoyi.invest.service.ITProjectContractService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;
import org.springframework.web.multipart.MultipartFile;

/**
 * 合同管理Controller
 * 
 * @author ruoyi
 * @date 2024-02-23
 */
@Api(tags = "合同管理")
@RestController
@RequestMapping("/invest/contract")
public class TProjectContractController extends BaseController
{
    @Autowired
    private ITProjectContractService tProjectContractService;

    @Autowired
    private ITProjectCirculationService tProjectCirculationService;

    @Autowired
    private ITUnifyFileService tUnifyFileService;

    @Autowired
    private ISysDictDataService dictDataService;

    /**
     * 查询合同管理列表
     */
    @ApiOperation("查询合同管理列表")
    @PreAuthorize("@ss.hasPermi('invest:contract:list')")
    @GetMapping("/list")
    public TableDataInfo list(TProjectContract tProjectContract)
    {
        startPage();
        List<TProjectContract> list = tProjectContractService.selectTProjectContractList(tProjectContract);
        return getDataTable(list);
    }

    /**
     * 导出合同管理列表
     */
    @ApiOperation("导出合同管理列表")
    @PreAuthorize("@ss.hasPermi('invest:contract:export')")
    @Log(title = "合同管理", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, TProjectContract tProjectContract)
    {
        List<TProjectContract> list = tProjectContractService.selectTProjectContractList(tProjectContract)
                .stream().map(n -> {
                    n.setProjectPoolId(n.gettProjectPool().getProjectName());
                    n.setContractType(dictDataService.selectDictLabel("contract_type",n.getContractType()));
                    n.setProjectStage(dictDataService.selectDictLabel("project_stage",n.getProjectStage()));
                    return n;
                })
                .collect(Collectors.toList());
        ExcelUtil<TProjectContract> util = new ExcelUtil<TProjectContract>(TProjectContract.class);
        util.exportExcel(response, list, "合同管理数据");
    }

    /**
     * 获取合同管理详细信息
     */
    @ApiOperation("获取合同管理详细信息")
    @PreAuthorize("@ss.hasPermi('invest:contract:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") String id)
    {
        return success(tProjectContractService.selectTProjectContractById(id));
    }

    /**
     * 新增合同管理
     */
    @ApiOperation("新增合同管理")
    @PreAuthorize("@ss.hasPermi('invest:contract:add')")
    @Log(title = "合同管理", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody TProjectContract tProjectContract)
    {
        tProjectContract.setId(IdUtils.fastSimpleUUID());
        tProjectContract.setCreateBy(getNickName());

        // todo 保存附件信息
        tUnifyFileService.insertTUnifyFileList(tProjectContract.getListFile(),
                tProjectContract.getProjectPoolId(),
                tProjectContract.getId(),//合同ID
                String.valueOf(FileType.CONTRACT.ordinal()),//文件类型:合同
                getNickName());

        // todo 增加合同创建记录
        tProjectCirculationService.insertTProjectCirculation(tProjectContract.getProjectPoolId(),tProjectContract.getContractName()+"(合同)",getNickName());

        return toAjax(tProjectContractService.insertTProjectContract(tProjectContract));
    }

    /**
     * 修改合同管理
     */
    @ApiOperation("修改合同管理")
    @PreAuthorize("@ss.hasPermi('invest:contract:edit')")
    @Log(title = "合同管理", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody TProjectContract tProjectContract)
    {
        // todo 保存附件信息
        tUnifyFileService.insertTUnifyFileList(tProjectContract.getListFile(),
                tProjectContract.getProjectPoolId(),
                tProjectContract.getId(),//合同ID
                String.valueOf(FileType.CONTRACT.ordinal()),//文件类型:合同
                getNickName());

        return toAjax(tProjectContractService.updateTProjectContract(tProjectContract));
    }

    /**
     * 删除合同管理
     */
    @ApiOperation("删除合同管理")
    @PreAuthorize("@ss.hasPermi('invest:contract:remove')")
    @Log(title = "合同管理", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable String[] ids)
    {
        //删除附件
        tUnifyFileService.updateTUnifyFileBusinessIds(ids);
        return toAjax(tProjectContractService.deleteTProjectContractByIds(ids));
    }
}
