package com.ruoyi.invest.service.impl;

import java.util.List;
import com.ruoyi.common.utils.DateUtils;
import com.ruoyi.common.utils.uuid.IdUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.invest.mapper.TProjectReviewMapper;
import com.ruoyi.invest.domain.TProjectReview;
import com.ruoyi.invest.service.ITProjectReviewService;

/**
 * 评审记录Service业务层处理
 * 
 * @author zjc
 * @date 2024-04-02
 */
@Service
public class TProjectReviewServiceImpl implements ITProjectReviewService 
{
    @Autowired
    private TProjectReviewMapper tProjectReviewMapper;

    /**
     * 查询评审记录
     * 
     * @param id 评审记录主键
     * @return 评审记录
     */
    @Override
    public TProjectReview selectTProjectReviewById(String id)
    {
        return tProjectReviewMapper.selectTProjectReviewById(id);
    }

    /**
     * 查询评审记录列表
     * 
     * @param tProjectReview 评审记录
     * @return 评审记录
     */
    @Override
    public List<TProjectReview> selectTProjectReviewList(TProjectReview tProjectReview)
    {
        return tProjectReviewMapper.selectTProjectReviewList(tProjectReview);
    }

    /**
     * 新增评审记录
     * 
     * @param tProjectReview 评审记录
     * @return 结果
     */
    @Override
    public int insertTProjectReview(TProjectReview tProjectReview)
    {
        tProjectReview.setCreateTime(DateUtils.getNowDate());
        tProjectReview.setId(IdUtils.fastSimpleUUID());
        return tProjectReviewMapper.insertTProjectReview(tProjectReview);
    }

    /**
     * 修改评审记录
     * 
     * @param tProjectReview 评审记录
     * @return 结果
     */
    @Override
    public int updateTProjectReview(TProjectReview tProjectReview)
    {
        tProjectReview.setUpdateTime(DateUtils.getNowDate());
        return tProjectReviewMapper.updateTProjectReview(tProjectReview);
    }

    /**
     * 批量删除评审记录
     * 
     * @param ids 需要删除的评审记录主键
     * @return 结果
     */
    @Override
    public int deleteTProjectReviewByIds(String[] ids)
    {
        return tProjectReviewMapper.deleteTProjectReviewByIds(ids);
    }

    /**
     * 删除评审记录信息
     * 
     * @param id 评审记录主键
     * @return 结果
     */
    @Override
    public int deleteTProjectReviewById(String id)
    {
        return tProjectReviewMapper.deleteTProjectReviewById(id);
    }
}
